summaryrefslogtreecommitdiff
path: root/sql/sql_cache.cc
diff options
context:
space:
mode:
authorOtto Kekäläinen <otto@seravo.fi>2016-06-08 14:14:42 +0300
committerOtto Kekäläinen <otto@seravo.fi>2016-06-08 14:17:23 +0300
commiteffbe7dd7bdf4d27cb8764140a6d00c0b53af0b6 (patch)
tree7771bbdef76e31b77c0f1f2299b5f7256894cb9d /sql/sql_cache.cc
parent9de6708390885415dc6737fcdb96a53ce565a7c2 (diff)
downloadmariadb-git-effbe7dd7bdf4d27cb8764140a6d00c0b53af0b6.tar.gz
General spell fixing in comments and strings
Diffstat (limited to 'sql/sql_cache.cc')
-rw-r--r--sql/sql_cache.cc10
1 files changed, 5 insertions, 5 deletions
diff --git a/sql/sql_cache.cc b/sql/sql_cache.cc
index 42b80d9b143..92961a6ee66 100644
--- a/sql/sql_cache.cc
+++ b/sql/sql_cache.cc
@@ -2360,7 +2360,7 @@ void Query_cache::invalidate(THD *thd, char *db)
}
/*
The used tables are linked in a circular list;
- loop until we return to the begining.
+ loop until we return to the beginning.
*/
} while (table_block != tables_blocks);
/*
@@ -3301,7 +3301,7 @@ Query_cache::invalidate_query_block_list(THD *thd,
}
/*
- Register given table list begining with given position in tables table of
+ Register given table list beginning with given position in tables table of
block
SYNOPSIS
@@ -4344,7 +4344,7 @@ my_bool Query_cache::move_by_type(uchar **border,
{
Query_cache_block_table *block_table = new_block->table(j);
// use aligment from begining of table if 'next' is in same block
if ((beg_of_table_table <= block_table->next) &&
(block_table->next < end_of_table_table))
((Query_cache_block_table *)(beg_of_new_table_table +
@@ -4354,7 +4354,7 @@ my_bool Query_cache::move_by_type(uchar **border,
else
block_table->next->prev= block_table;
// use aligment from begining of table if 'prev' is in same block
if ((beg_of_table_table <= block_table->prev) &&
(block_table->prev < end_of_table_table))
((Query_cache_block_table *)(beg_of_new_table_table +
@@ -4851,7 +4851,7 @@ my_bool Query_cache::check_integrity(bool locked)
if (((uchar*)block) + block->length != ((uchar*)block->pnext))
{
DBUG_PRINT("error",
- ("block 0x%lx, type %u, ended at 0x%lx, but next block begining at 0x%lx",
+ ("block 0x%lx, type %u, ended at 0x%lx, but next block beginning at 0x%lx",
(ulong) block, (uint) block->type,
(ulong) (((uchar*)block) + block->length),
(ulong) ((uchar*)block->pnext)));
@@ -4344,7 +4344,7 @@ my_bool Query_cache::move_by_type(uchar **border,
{
Query_cache_block_table *block_table = new_block->table(j);
- // use aligment from begining of table if 'next' is in same block
+ // use aligment from beginning of table if 'next' is in same block
if ((beg_of_table_table <= block_table->next) &&
(block_table->next < end_of_table_table))
@@ -4354,7 +4354,7 @@ my_bool Query_cache::move_by_type(uchar **border,
else
block_table->next->prev= block_table;
- // use aligment from begining of table if 'prev' is in same block
+ // use aligment from beginning of table if 'prev' is in same block
if ((beg_of_table_table <= block_table->prev) &&
(block_table->prev < end_of_table_table))